@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Newest.pm,v 1.29 2010-11-30 20:57:53 dpchrist Exp $
+# $Id: Newest.pm,v 1.30 2010-12-03 05:13:50 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK	= ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT	= qw();
 
-our $VERSION	= sprintf "%d.%03d", q$Revision: 1.29 $ =~ /(\d+)/g;
+our $VERSION	= sprintf "%d.%03d", q$Revision: 1.30 $ =~ /(\d+)/g;
 
 #######################################################################
 # uses:
@@ -57,7 +57,7 @@ Dpchrist::File::Newest - find newest files
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.29 $.
+This documentation describes module revision $Revision: 1.30 $.
 
 
 This is alpha test level software
@@ -182,8 +182,6 @@ All of the subroutines may be imported by using the ':all' tag:
 
     use Dpchrist::File::Newest    qw( :all );
 
-See 'perldoc Export' for everything in between.
-
 
 =head1 INSTALLATION
 
@@ -202,13 +200,6 @@ Complete:
 
     $ cpan Bundle::Dpchrist
 
-The following warning may be safely ignored:
-
-    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
-    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
-    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
-    /usr/local/lib/site_perl .) at Makefile.PL line 22.
-
 
 =head2 PREREQUISITES
 
